Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(211)

Unified Diff: components/exo/shell_surface.cc

Issue 2771663005: Add black background to ARC maximzied window as well as fullscreen. (Closed)
Patch Set: Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | components/exo/shell_surface_unittest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/exo/shell_surface.cc
diff --git a/components/exo/shell_surface.cc b/components/exo/shell_surface.cc
index 8b61a9d121e7169dea7f1cf3e1f7be42053fc4b9..5789f7c7cf8f37474903250c2f31961eb512c586 100644
--- a/components/exo/shell_surface.cc
+++ b/components/exo/shell_surface.cc
@@ -1517,14 +1517,16 @@ void ShellSurface::UpdateShadow() {
widget_->IsActive();
float shadow_underlay_opacity = shadow_background_opacity_;
+
// Put the black background layer behind the window if
// 1) the window is in immersive fullscreen or is active with
// spoken feedback enabled.
// 2) the window can control the bounds of the window in fullscreen (
// thus the background can be visible).
// 3) the window has no transform (the transformed background may
// not cover the entire background, e.g. overview mode).
- if ((widget_->IsFullscreen() || underlay_capture_events) &&
+ if ((widget_->IsFullscreen() || widget_->IsMaximized() ||
+ underlay_capture_events) &&
ash::wm::GetWindowState(window)->allow_set_bounds_in_maximized() &&
window->layer()->GetTargetTransform().IsIdentity()) {
if (shadow_underlay_in_surface_) {
@@ -1517,14 +1517,16 @@ void ShellSurface::UpdateShadow() {
// Put the black background layer behind the window if
- // 1) the window is in immersive fullscreen or is active with
+ // 1) the window is in immersive fullscreen, maximized or is active with
// spoken feedback enabled.
// 2) the window can control the bounds of the window in fullscreen (
« no previous file with comments | « no previous file | components/exo/shell_surface_unittest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698